opencv_compatible_img_extensions = [
    'jpg', 'JPG',
    'jpeg', 'JPEG',
    'jpe', 'JPE',
    'png', 'PNG',
    'bmp', 'BMP',
    'pbm', 'PBM',
    'pgm', 'PGM',
    'ppm', 'PPM',
    'sr', 'SR',
    'ras', 'RAS',
    'jp2', 'JP2',
    'tiff', 'TIFF',
    'tif', 'TIF'
]

opencv_compatible_video_extensions = [
    'mp4', 'MP4',
    'avi', 'AVI',
    'mov', 'MOV'
]